SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetStudyResultSummary]
(
	@VCC					VARCHAR(50),
	@StudyId				VARCHAR(200),
	@NewStructure			VARCHAR(1)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		SELECT
			B.[Name]						'processName',
			A.[Name]						'studyName',
			A.[Description]					'studyDescription',
			A.[TemplateId]					'templateId'
		FROM [dbo].[Study] A (NOLOCK)
		INNER JOIN Process B ON A.ProcessId = B.[Name]
		WHERE A.[VCC] = @VCC 
			AND A.[Name] = @StudyId
	END
	
	BEGIN
		SELECT SRS.[VCC]							'vcc',
				SRS.[StudyId]						'studyId',
				SRS.[TemplateId]					'templateId',
				SRS.[TemplateThemeId]				'templateThemeId',
				SRS.[ID]							'id',
				SRS.[Description]					'description',
				SRS.[Category1]						'category1',
				SRS.[Category2]						'category2',
				SRS.[Total]							'total',
				SRS.[Duration]						'duration',
				SRS.[Silence]						'silence',
				SRS.[Confidence]					'confidence',
				SRS.[CreatedDate]					'createdDate',
				SRS.[CreatedByUserId]				'createdByUserId',
				SRS.[LastModifiedDate]				'lastModifiedDate',
				SRS.[LastModifiedByUserId]			'lastModifiedByUserId'
			FROM [dbo].[StudyResultSummary] SRS (NOLOCK)
			WHERE SRS.[VCC] = @VCC 
				AND SRS.[StudyId] = @StudyId
	END

	IF(@NewStructure IS NULL)
	BEGIN

		-- CREAMOS UNA TEMPORAL PARA AUDIOS Y ASYNCINTERACTIONS
		CREATE TABLE #INNER_INTERACTION (
			[VCC] VARCHAR(50),
			[Channel] VARCHAR(50),
			[ID] VARCHAR(100),
			[Section] NUMERIC(5,0),
			[Part] NUMERIC(5,0), 
			[Campaign] VARCHAR(100),
			[Agent] VARCHAR(50),
			[IsTranscribed] BIT,
			[IsCancel] BIT,
			[Folder] VARCHAR(100),
			[TranscriptionId] VARCHAR(250),
			
		)

		-- INSERTAMOS LOS Audios 
		INSERT INTO #INNER_INTERACTION
				SELECT AU.[VCC],
					AU.[Channel], 
					AU.[ID], 
					AU.[Section], 
					AU.[Part], 
					AU.[Campaign], 
					AU.[agent], 
					AU.[IsTranscribed], 
					AU.[IsCancel],
					null as 'Folder',
					CONCAT(AU.[ID], '_', AU.[Section], '_', AU.[Part]) AS 'TranscriptionId'
				
				FROM [dbo].[Audio] AU (NOLOCK)
				INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK)
					ON AU.[VCC] = PA.[VCC]
					AND AU.[ID] = PA.[AudioId]
				INNER JOIN [dbo].[Study] ST (NOLOCK)
					ON PA.[ProcessId] = ST.[processId]
				WHERE 
				AU.[VCC] IN ('system', @VCC) AND
				ST.[Name] = @StudyId

		-- INSERTAMOS LOS AsyncInteraction 
		INSERT INTO #INNER_INTERACTION
				SELECT 
				AI.[VCC], 
				AI.[Channel], 
				AI.[ID], 
				null as 'Section',
				null as 'Part',
				AI.[Campaign], 
				AI.[FirstTakedAgent] AS 'Agent', 
				AI.[IsTranscribed], 
				AI.[IsCancel],
				AI.[Folder],
				CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_')) AS 'TranscriptionId'
			
			FROM [dbo].[AsyncInteraction] AI (NOLOCK)
			INNER JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
				AND AI.[ID] = PAI.[InteractionId]
			INNER JOIN [dbo].[Study] ST (NOLOCK)
				ON ST.[processId] = PAI.[ProcessId]
			WHERE 
			AI.[VCC] IN ('system', @VCC) AND
			ST.[Name] = @StudyId		

		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			--ISNULL(D.[Query], A.[TemplateThemeItemId])			'query', -- Si es NULL se mostrara valor de TemplateThemeItem campo ID.
			ISNULL(ISNULL(D.[Query], E.[EntityName]),'')			'query', -- Si es NULL se mostrara valor de TemplateThemeItem campo ID.
			C.[Channel]											'interactionType',
			S.[ProcessId]										'processId',
			C.[ID]								                'transcriptionId',
			C.[Section]											'section',
			C.[Part]											'part',
			C.[Folder]											'folder',
			C.[Campaign]										'campaign',
			C.[Agent]		                                    'agent',
			C.[IsTranscribed]		                            'isTranscribed',
			C.[IsCancel]				                        'isCancel'
		FROM [dbo].[StudyResultSummaryDetail] A (NOLOCK)
		INNER JOIN [dbo].[Study] S (NOLOCK) 
			ON S.[VCC] = A.[VCC] 
				AND S.[Name] = A.[StudyId]
		INNER JOIN [dbo].[HistoricTemplateThemeItem] B (NOLOCK) 
			ON S.[TemplateId] = B.[TemplateId] 
				AND A.[TemplateThemeId] = B.[TemplateThemeId] 
				AND A.[TemplateThemeItemId] = B.[ID]
				AND B.[StudyId] = S.[Name]
			
		INNER JOIN [dbo].[#INNER_INTERACTION] C (NOLOCK)  -- (!)SE CAMBIO EL INNER POR LEFT PARA CONSIDER LAS TRANSCRIPCIONES DE CANALES ASINCRINOS
			ON A.[VCC] = C.[VCC]
				AND A.[TranscriptionId] = C.[TranscriptionId]
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON S.[VCC] = PA.[VCC] 
				AND S.[ProcessId] = PA.[ProcessId] 
				AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])

		--LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			-- ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
		LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			ON PAI.[VCC] = S.[VCC]
				AND PAI.[ProcessId] = S.[ProcessId]
				AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

		LEFT JOIN [dbo].[GenericQuery] D (NOLOCK) 
			ON B.[VCC] = D.[VCC] 
				AND  B.[ID] = D.[Name] -- Se agrega LEFT JOIN para poder mostrar.

		LEFT JOIN [dbo].[TemplateThemeItemEntity] E 
			ON A.TemplateThemeId = E.TemplateThemeId
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId

		DROP TABLE #INNER_INTERACTION		
	END
	ELSE
	BEGIN
		-- ESTE BLOQUE NUNCA SE USA, EL UNICO LLAMADO DE LA FUNCION INSERTA DIRECTAMENTE NULL PARA LA VARIABLE @NewStructure
		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			D.[Query]											'query',
			ISNULL(C.[Channel], AI.[Channel])					'interactionType',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN A.[TranscriptionId] 
				ELSE AI.[ID] END								'transcriptionId',
			C.[Section]											'section',
			C.[Part]											'part',
			AI.[Folder]											'folder',
			AI.[Campaign]										'campaign',
			--ISNULL(C.[Agent], '')								'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[Agent], '') 
				ELSE ISNULL(AI.[FirstTakedAgent], '') END		'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsTranscribed], '') 
				ELSE ISNULL(AI.[IsTranscribed], '') END			'isTranscribed',
			CASE WHEN C.[Channel] IS NOT NULL
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsCancel], '') 
				ELSE ISNULL(AI.[IsCancel], '') END				'isCancel'
			
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) 
				ON S.[VCC] = A.[VCC] 
					AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[HistoricTemplateThemeItem] B (NOLOCK) 
				ON S.[TemplateId] = B.[TemplateId] 
					AND A.[TemplateThemeId] = B.[TemplateThemeId] 
					AND A.[TemplateThemeItemId] = B.[ID]
					AND B.[StudyId] = S.[Name]
			
			LEFT JOIN [dbo].[Audio] C (NOLOCK) 
				ON A.[VCC] = C.[VCC]
					AND A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON S.[VCC] = PA.[VCC] 
					AND S.[ProcessId] = PA.[ProcessId] 
					AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = S.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

			INNER JOIN [dbo].[GenericQuery] D (NOLOCK) 
				ON B.[VCC] = D.[VCC] 
					AND  B.[ID] = D.[Name]
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
